@@ -55,6 +55,8 @@ class CatalogEntry(object):
             result['stream'] = self.stream
         if self.row_count is not None:
             result['row_count'] = self.row_count
+        if self.stream_alias is not None:
+            result['stream_alias'] = self.stream_alias
         if self.metadata is not None:
             result['metadata'] = self.metadata
         return result
@@ -95,6 +97,7 @@ class Catalog(object):
             entry.schema = Schema.from_dict(stream.get('schema'))
             entry.is_view = stream.get('is_view')
             entry.stream_alias = stream.get('stream_alias')
+            entry.metadata = stream.get('metadata')
             streams.append(entry)
         return Catalog(streams)
 
